@@ -5,7 +5,7 @@ static char rcsid[] = "$Id: context.c 769 2007-10-24 00:15:40Z hubert@u.washingt
 /*
  * ========================================================================
  * Copyright 2006-2007 University of Washington
- * Copyright 2013-2015 Eduardo Chappa
+ * Copyright 2013-2017 Eduardo Chappa
  *
  * Licensed under the Apache License, Version 2.0 (the "License");
  * you may not use this file except in compliance with the License.
@@ -275,7 +275,7 @@ go_again:
     memset(&screen, 0, sizeof(screen));
     screen.ro_warning = readonly_warning;
     ret = conf_scroll_screen(ps, &screen, first_line, cs->title,
-			     cs->print_string, 0);
+			     cs->print_string, 0, NULL);
 
     free_contexts(&top);
     
@@ -470,7 +470,7 @@ context_select_screen(struct pine *ps, CONT_SCR_S *cs, int ro_warn)
     memset(&screen, 0, sizeof(screen));
     screen.ro_warning = readonly_warning;
     (void) conf_scroll_screen(ps, &screen, first_line, cs->title,
-			      cs->print_string, 0);
+			      cs->print_string, 0, NULL);
     opt_screen = saved_screen;
     ps->mangled_screen = 1;
     return(cs->selected);
