@@ -4,8 +4,8 @@ static char rcsid[] = "$Id: init.c 769 2007-10-24 00:15:40Z hubert@u.washington.
 
 /*
  * ========================================================================
+ * Copyright 2013-2017 Eduardo Chappa
  * Copyright 2006-2007 University of Washington
- * Copyright 2013-2015 Eduardo Chappa
  *
  * Licensed under the Apache License, Version 2.0 (the "License");
  * you may not use this file except in compliance with the License.
@@ -378,8 +378,8 @@ get_mail_list(CONTEXT_S *list_cntxt, char *folder_base)
 	folder_base_len = strlen(searchname) - 1;
     }
     else
-#endif
-    snprintf(searchname, sizeof(searchname), "%.*s*", sizeof(searchname)-2, folder_base);
+#endif					/* MAXPATH + 1 = sizeof(searchmane) */
+    snprintf(searchname, sizeof(searchname), "%.*s*", MAXPATH+1-2, folder_base);
 
     build_folder_list(NULL, list_cntxt, searchname, NULL, BFL_FLDRONLY);
 
