@@ -4,8 +4,8 @@ static char rcsid[] = "$Id: state.c 1074 2008-06-04 00:08:43Z hubert@u.washingto
 
 /*
  * ========================================================================
+ * Copyright 2013-2017 Eduardo Chappa
  * Copyright 2006-2008 University of Washington
- * Copyright 2013-2015 Eduardo Chappa
  *
  * Licensed under the Apache License, Version 2.0 (the "License");
  * you may not use this file except in compliance with the License.
@@ -116,6 +116,9 @@ free_pine_struct(struct pine **pps)
     if(!(pps && (*pps)))
       return;
 
+    if((*pps)->id != NULL)
+      mail_free_idlist(&(*pps)->id);
+
     if((*pps)->hostname != NULL)
       fs_give((void **)&(*pps)->hostname);
 
@@ -175,10 +178,10 @@ free_pine_struct(struct pine **pps)
     if((*pps)->posting_charmap)
       fs_give((void **)&(*pps)->posting_charmap);
 
-#ifdef PASSFILE
-    if((*pps)->passfile)
-      fs_give((void **)&(*pps)->passfile);
 #ifdef SMIME
+    if((*pps)->pwdcertdir)
+      fs_give((void **)&(*pps)->pwdcertdir);
+
     if((*pps)->pwdcert){
       PERSONAL_CERT *pc;
 
@@ -186,9 +189,28 @@ free_pine_struct(struct pine **pps)
       free_personal_certs(&pc);
       (*pps)->pwdcert = NULL;
     }
-    if((*pps)->pwdcertdir)
-      fs_give((void **)&(*pps)->pwdcertdir);
-#endif /* SMIME inside PASSFILE */
+
+    if((*pps)->pwdcertlist){
+	CertList *cert;
+
+	cert = (CertList *) (*pps)->pwdcertlist;
+	free_certlist(&cert);
+	(*pps)->pwdcertlist = NULL;
+    }
+
+    if((*pps)->backuppassword){
+	CertList *cert;
+
+	cert = (CertList *) (*pps)->backuppassword;
+	free_certlist(&cert);
+	(*pps)->backuppassword = NULL;
+    }
+#endif /* SMIME */
+
+
+#ifdef PASSFILE
+    if((*pps)->passfile)
+      fs_give((void **)&(*pps)->passfile);
 #endif /* PASSFILE */
 
     if((*pps)->hdr_colors)
